@@ -1,22 +1,22 @@
 import os
+import stat
 from typing import List
 
-from atcodertools.codegen.code_generator import CodeGenerator
-from atcodertools.models.constpred.problem_constant_set import ProblemConstantSet
-from atcodertools.models.sample import Sample
-from atcodertools.models.predictor.format_prediction_result import FormatPredictionResult
+from atcodertools.client.models.sample import Sample
 
 
 def _make_text_file(file_path, text):
+    os.makedirs(os.path.dirname(file_path), exist_ok=True)
     with open(file_path, 'w') as f:
         f.write(text)
 
 
-def create_code_from(result: FormatPredictionResult,
-                     constants: ProblemConstantSet,
-                     code_generator: CodeGenerator,
-                     file_path: str):
-    _make_text_file(file_path, code_generator.generate_code(result, constants))
+def create_code(source_code: str,
+                file_path: str):
+    _make_text_file(file_path, source_code)
+    if source_code.startswith('#!'):
+        st = os.stat(file_path)
+        os.chmod(file_path, st.st_mode | stat.S_IEXEC)
 
 
 def create_example(example: Sample, in_example_name: str, out_example_name: str):
